@@ -30,12 +30,17 @@
 #include "champlain/champlain-version.h"
 
 #include "champlain/champlain-layer.h"
-#include "champlain/champlain-selection-layer.h"
+#include "champlain/champlain-marker-layer.h"
+#include "champlain/champlain-path-layer.h"
 #include "champlain/champlain-point.h"
-#include "champlain/champlain-base-marker.h"
+#include "champlain/champlain-custom-marker.h"
+#include "champlain/champlain-location.h"
+#include "champlain/champlain-coordinate.h"
 #include "champlain/champlain-marker.h"
+#include "champlain/champlain-label.h"
 #include "champlain/champlain-view.h"
 #include "champlain/champlain-bounding-box.h"
+#include "champlain/champlain-scale.h"
 
 #include "champlain/champlain-map-source.h"
 #include "champlain/champlain-tile-source.h"
